@@ -197,11 +197,11 @@ class Tool:
         text = text.replace('\n', '').replace('\t', '').replace('\r', '').replace(' ', '').replace('\xa0', '')
         return text
 
-    def get_html(self, url, headers={}, proxy={}, timeout=5, debug=False):
+    def get_html(self, url, headers={}, proxy={}, cookies={}, data={}, timeout=5, debug=False):
 
         for i in range(5):
             try:
-                res = self.session.get(url, headers=headers, timeout=timeout, proxies=proxy)
+                res = self.session.get(url, headers=headers, timeout=timeout, proxies=proxy, cookies=cookies, data=data)
                 return res
             except Exception as e:
                 if debug:
@@ -209,11 +209,11 @@ class Tool:
         else:
             return False
 
-    def post_html(self, url, headers={}, data={}, json={}, proxy={}, timeout=5, debug=False):
+    def post_html(self, url, headers={}, data={}, json={}, proxy={}, cookies={}, timeout=5, debug=False):
 
         for i in range(5):
             try:
-                res = self.session.post(url, data=data, json=json, headers=headers, timeout=timeout, proxies=proxy)
+                res = self.session.post(url, data=data, json=json, headers=headers, timeout=timeout, proxies=proxy, cookies=cookies)
                 return res
             except Exception as e:
                 if debug:
@@ -250,7 +250,7 @@ class Tool:
         while 1:
             try:
                 connection = pymysql.connect(host=self.db_config['host'], port=self.db_config['port'], user=self.db_config['user'], password=self.db_config['password'],
-                                             db=self.db, charset='utf8', cursorclass=pymysql.cursors.DictCursor)
+                                             db=self.db, charset='utf8mb4', cursorclass=pymysql.cursors.DictCursor)
                 return connection
             except Exception as e:
                 print(e)
